@@ -9,11 +9,10 @@
 #include "caffeine-quick-setting.h"
 #include "phosh-plugin.h"
 
-#include <gio/gio.h>
-#include <gtk/gtk.h>
 
 char **g_io_phosh_plugin_caffeine_quick_setting_query (void);
 
+
 void
 g_io_module_load (GIOModule *module)
 {
@@ -25,11 +24,13 @@ g_io_module_load (GIOModule *module)
                                   10);
 }
 
+
 void
 g_io_module_unload (GIOModule *module)
 {
 }
 
+
 char **
 g_io_phosh_plugin_caffeine_quick_setting_query (void)
 {
