@@ -1,5 +1,6 @@
 /*
  * Copyright (C) 2024 The Phosh Developers
+ *               2025 Phosh.mobi e.V.
  *
  * SPDX-License-Identifier: GPL-3.0-or-later
  *
@@ -9,10 +10,7 @@
 #include "pomodoro-quick-setting.h"
 #include "pomodoro-enums.h"
 #include "plugin-shell.h"
-#include "quick-setting.h"
-#include "notification.h"
 #include "notify-manager.h"
-#include "status-icon.h"
 
 #include <cui-call.h>
 
@@ -22,6 +20,8 @@
 #define ACTIVE_ICON    "pomodoro-active-symbolic"
 #define BREAK_ICON     "pomodoro-break-symbolic"
 
+#define START_ON_UNLOCK_KEY "start-on-unlock"
+
 /**
  * PhoshPomodoroQuickSetting:
  *
@@ -47,6 +47,7 @@ struct _PhoshPomodoroQuickSetting {
 
 G_DEFINE_TYPE (PhoshPomodoroQuickSetting, phosh_pomodoro_quick_setting, PHOSH_TYPE_QUICK_SETTING);
 
+static gboolean _started_on_login;
 
 static void
 phosh_pomodoro_quick_setting_clear_timers (PhoshPomodoroQuickSetting *self)
@@ -186,6 +187,25 @@ phosh_pomodoro_quick_setting_set_state (PhoshPomodoroQuickSetting *self, PhoshPo
 }
 
 
+static void
+on_shell_locked (PhoshPomodoroQuickSetting *self, GParamSpec *pspec, PhoshShell *shell)
+{
+  g_assert (PHOSH_IS_SHELL (shell));
+  g_assert (PHOSH_IS_POMODORO_QUICK_SETTING (self));
+
+  if (phosh_shell_get_locked (shell))
+    return;
+
+  if (self->state != PHOSH_POMODORO_STATE_OFF)
+    return;
+
+  if (!g_settings_get_boolean (self->settings, START_ON_UNLOCK_KEY))
+    return;
+
+  phosh_pomodoro_quick_setting_set_state (self, PHOSH_POMODORO_STATE_ACTIVE);
+}
+
+
 static void
 phosh_pomodoro_quick_setting_set_property (GObject      *object,
                                            guint         property_id,
@@ -355,5 +375,16 @@ phosh_pomodoro_quick_setting_init (PhoshPomodoroQuickSetting *self)
                                G_BINDING_DEFAULT | G_BINDING_SYNC_CREATE,
                                transform_to_icon_name,
                                NULL, NULL, NULL);
+
+  g_signal_connect_object (phosh_shell_get_default (),
+                           "notify::locked",
+                           G_CALLBACK (on_shell_locked),
+                           self,
+                           G_CONNECT_SWAPPED);
+  if (g_settings_get_boolean (self->settings, START_ON_UNLOCK_KEY) && !_started_on_login) {
+    phosh_pomodoro_quick_setting_set_state (self, PHOSH_POMODORO_STATE_ACTIVE);
+    _started_on_login = TRUE;
+  }
+
   update_label (self);
 }
