@@ -20,5 +20,10 @@ G_DECLARE_FINAL_TYPE (PhoshBrightnessManager, phosh_brightness_manager, PHOSH, B
 PhoshBrightnessManager *phosh_brightness_manager_new (void);
 GtkAdjustment *         phosh_brightness_manager_get_adjustment (PhoshBrightnessManager *self);
 gboolean                phosh_brightness_manager_get_auto_brightness_enabled (PhoshBrightnessManager *self);
+double                  phosh_brightness_manager_get_value (PhoshBrightnessManager *self);
+void                    phosh_brightness_manager_set_value (PhoshBrightnessManager *self,
+                                                            double                  value,
+                                                            gboolean                osd);
+
 
 G_END_DECLS
