@@ -1,5 +1,6 @@
 /*
  * Copyright (C) 2020 Purism SPC
+ *               2025 Phosh.mobi e.V.
  *
  * SPDX-License-Identifier: GPL-3.0-or-later
  *
@@ -12,9 +13,7 @@
 #include "phosh-config.h"
 
 #include "gnome-shell-manager.h"
-#include "osd-window.h"
 #include "shell-priv.h"
-#include "util.h"
 #include "lockscreen-manager.h"
 
 #define GNOME_DESKTOP_USE_UNSTABLE_API
@@ -30,7 +29,6 @@
  */
 
 #define GNOME_SHELL_DBUS_NAME "org.gnome.Shell"
-#define OSD_HIDE_TIMEOUT 1 /* seconds */
 
 static void phosh_gnome_shell_manager_gnome_shell_iface_init (PhoshDBusGnomeShellIface *iface);
 
@@ -54,10 +52,6 @@ typedef struct _PhoshGnomeShellManager {
   guint                       repeat_delay_ms;
   guint                       repeat_interval_ms;
 
-  PhoshOsdWindow             *osd;
-  gint                        osd_timeoutid;
-  gboolean                    osd_continue;
-
   gboolean                    overview_active;
 } PhoshGnomeShellManager;
 
@@ -72,15 +66,15 @@ static void accelerator_activated_action (GSimpleAction *action, GVariant *param
 
 typedef struct _AcceleratorInfo {
   guint                            action_id;
-  gchar                           *accelerator;
-  gchar                           *sender;
+  char                            *accelerator;
+  char                            *sender;
   guint                            mode_flags;
   guint                            grab_flags;
   guint                            repeat_id;
 } AcceleratorInfo;
 
 static void
-remove_action_entries (gchar *accelerator)
+remove_action_entries (char *accelerator)
 {
   GStrv action_names = (char*[]){ accelerator, NULL };
 
@@ -136,28 +130,6 @@ handle_hide_monitor_labels (PhoshDBusGnomeShell   *skeleton,
 }
 
 
-static gboolean
-on_osd_timeout (PhoshGnomeShellManager *self)
-{
-  gboolean ret;
-  ret = self->osd_continue ? G_SOURCE_CONTINUE : G_SOURCE_REMOVE;
-  if (!self->osd_continue) {
-    g_debug ("Closing osd");
-    self->osd_timeoutid = 0;
-    if (self->osd)
-      gtk_widget_destroy (GTK_WIDGET (self->osd));
-  }
-  self->osd_continue = FALSE;
-  return ret;
-}
-
-
-static void
-on_osd_destroyed (PhoshGnomeShellManager *self)
-{
-  self->osd = NULL;
-  g_clear_handle_id (&self->osd_timeoutid, g_source_remove);
-}
 
 
 static gboolean
@@ -167,7 +139,7 @@ handle_show_osd (PhoshDBusGnomeShell   *skeleton,
 {
   PhoshGnomeShellManager *self = PHOSH_GNOME_SHELL_MANAGER (skeleton);
   g_autofree char *connector = NULL, *icon = NULL, *label = NULL;
-  gdouble level = 0.0, maxlevel = 1.0;
+  double level = 0.0, maxlevel = 1.0;
   gboolean has_level;
   g_auto (GVariantDict) dict = G_VARIANT_DICT_INIT (NULL);
 
@@ -183,33 +155,9 @@ handle_show_osd (PhoshDBusGnomeShell   *skeleton,
   if (!has_level)
     level = -1.0;
 
-  g_debug ("DBus show osd: connector: %s icon: %s, label: %s, level %f/%f",
-           connector, icon, label, level, maxlevel);
+  phosh_shell_show_osd (phosh_shell_get_default (), connector, icon, label, level, maxlevel);
 
-  if (self->osd) {
-    self->osd_continue = TRUE;
-    g_object_set (self->osd,
-                  "connector", connector,
-                  "label", label,
-                  "icon-name", icon,
-                  "level", level,
-                  "max-level", maxlevel,
-                  NULL);
-  } else {
-    self->osd = PHOSH_OSD_WINDOW (phosh_osd_window_new (connector, label, icon, level, maxlevel));
-    g_signal_connect_swapped (self->osd, "destroy", G_CALLBACK (on_osd_destroyed), self);
-    gtk_widget_set_visible (GTK_WIDGET (self->osd), TRUE);
-  }
-
-  if (!self->osd_timeoutid) {
-    self->osd_timeoutid = g_timeout_add_seconds (OSD_HIDE_TIMEOUT,
-                                                 (GSourceFunc) on_osd_timeout,
-                                                 self);
-    g_source_set_name_by_id (self->osd_timeoutid, "[phosh] osd-timeout");
-  }
-
-  phosh_dbus_gnome_shell_complete_show_osd (
-    skeleton, invocation);
+  phosh_dbus_gnome_shell_complete_show_osd (skeleton, invocation);
 
   return TRUE;
 }
@@ -217,10 +165,10 @@ handle_show_osd (PhoshDBusGnomeShell   *skeleton,
 
 static guint
 grab_single_accelerator (PhoshGnomeShellManager *self,
-                         const gchar            *accelerator,
+                         const char             *accelerator,
                          guint                   mode_flags,
                          guint                   grab_flags,
-                         const gchar            *sender,
+                         const char             *sender,
                          GError                **error)
 {
   AcceleratorInfo *info;
@@ -273,13 +221,13 @@ grab_single_accelerator (PhoshGnomeShellManager *self,
 static gboolean
 handle_grab_accelerator (PhoshDBusGnomeShell   *skeleton,
                          GDBusMethodInvocation *invocation,
-                         const gchar           *arg_accelerator,
+                         const char            *arg_accelerator,
                          guint                  arg_modeFlags,
                          guint                  arg_grabFlags)
 {
   PhoshGnomeShellManager *self = PHOSH_GNOME_SHELL_MANAGER (skeleton);
   g_autoptr (GError) error = NULL;
-  const gchar * sender;
+  const char *sender;
   guint action_id;
 
   g_return_val_if_fail (PHOSH_IS_GNOME_SHELL_MANAGER (self), FALSE);
@@ -318,11 +266,11 @@ handle_grab_accelerators (PhoshDBusGnomeShell   *skeleton,
   PhoshGnomeShellManager *self = PHOSH_GNOME_SHELL_MANAGER (skeleton);
   g_autoptr (GVariantBuilder) builder = NULL;
   g_autoptr (GVariantIter) arg_iter = NULL;
-  gchar *accelerator_name;
+  char *accelerator_name;
   guint accelerator_mode_flags;
   guint accelerator_grab_flags;
   g_autoptr (GError) error = NULL;
-  const gchar *sender;
+  const char *sender;
   gboolean conflict = FALSE;
 
   g_return_val_if_fail (PHOSH_IS_GNOME_SHELL_MANAGER (self), FALSE);
@@ -386,7 +334,7 @@ handle_ungrab_accelerator (PhoshDBusGnomeShell   *skeleton,
   PhoshGnomeShellManager *self = PHOSH_GNOME_SHELL_MANAGER (skeleton);
   AcceleratorInfo *info;
   gboolean success = FALSE;
-  const gchar *sender;
+  const char *sender;
 
   g_return_val_if_fail (PHOSH_IS_GNOME_SHELL_MANAGER (self), FALSE);
   g_debug ("DBus ungrab accelerator (id %u)", arg_action);
@@ -420,7 +368,7 @@ handle_ungrab_accelerators (PhoshDBusGnomeShell   *skeleton,
   PhoshGnomeShellManager *self = PHOSH_GNOME_SHELL_MANAGER (skeleton);
   AcceleratorInfo *info;
   gboolean success = TRUE;
-  const gchar *sender;
+  const char *sender;
   g_return_val_if_fail (PHOSH_IS_GNOME_SHELL_MANAGER (self), FALSE);
 
   sender = g_dbus_method_invocation_get_sender (invocation);
@@ -541,10 +489,10 @@ do_activate_accelerator (AcceleratorInfo *info)
   g_assert (info);
 
   if ((info->mode_flags & self->action_mode) == 0) {
-    g_autofree gchar *str_shell_mode = g_flags_to_string (PHOSH_TYPE_SHELL_ACTION_MODE,
-                                                          self->action_mode);
-    g_autofree gchar *str_grabbed_mode = g_flags_to_string (PHOSH_TYPE_SHELL_ACTION_MODE,
-                                                            info->mode_flags);
+    g_autofree char *str_shell_mode = g_flags_to_string (PHOSH_TYPE_SHELL_ACTION_MODE,
+                                                         self->action_mode);
+    g_autofree char *str_grabbed_mode = g_flags_to_string (PHOSH_TYPE_SHELL_ACTION_MODE,
+                                                           info->mode_flags);
     g_debug ("Accelerator registered for mode %s, but shell is currently in %s",
              str_grabbed_mode,
              str_shell_mode);
