@@ -1,5 +1,6 @@
 /*
  * Copyright (C) 2020 Evangelos Ribeiro Tzaras
+ *               2025 Phosh.mobi e.V.
  *
  * SPDX-License-Identifier: GPL-3.0-or-later
  *
@@ -8,8 +9,9 @@
 
 #pragma once
 
-#include <stdint.h>
-#include <gtk/gtk.h>
+#include <gio/gio.h>
+
+G_BEGIN_DECLS
 
 #define PHOSH_TYPE_KEYBOARD_EVENTS (phosh_keyboard_events_get_type ())
 
@@ -19,5 +21,6 @@ G_DECLARE_FINAL_TYPE (PhoshKeyboardEvents,
                       KEYBOARD_EVENTS,
                       GSimpleActionGroup)
 
-PhoshKeyboardEvents  *phosh_keyboard_events_new           (void);
+PhoshKeyboardEvents  *phosh_keyboard_events_new           (GError **err);
 
+G_END_DECLS
