@@ -22,7 +22,7 @@
 #include "shell-priv.h"
 #include "util.h"
 #include "widget-box.h"
-#include "wall-clock.h"
+#include "wall-clock-priv.h"
 
 #include "gmobile.h"
 
@@ -79,31 +79,38 @@ typedef struct {
   gboolean            require_unlock;
 
   /* info page */
-  GtkWidget         *box_info;
-  GtkWidget         *box_datetime;
-  GtkListBox        *list_calls;
-  GtkWidget         *lbl_clock;
-  GtkWidget         *lbl_date;
-  GtkWidget         *list_notifications;
-  GtkRevealer       *rev_call_notifications;
-  GtkRevealer       *rev_media_player;
-  GtkRevealer       *rev_notifications;
-  GSettings         *notification_settings;
-  guint              reveals;
+  GtkWidget          *box_info;
+  GtkWidget          *box_datetime;
+  GtkListBox         *list_calls;
+  GtkWidget          *lbl_clock;
+  GtkWidget          *lbl_date;
+  GtkWidget          *list_notifications;
+  GtkRevealer        *rev_call_notifications;
+  GtkRevealer        *rev_media_player;
+  GtkRevealer        *rev_notifications;
+  GSettings          *notification_settings;
+  guint reveals;
 
   /* unlock page */
-  GtkWidget         *box_unlock;
-  GtkWidget         *keypad_revealer;
-  GtkWidget         *keypad;
-  GtkWidget         *entry_pin;
-  GtkGesture        *long_press_del_gesture;
-  GtkWidget         *lbl_unlock_status;
-  GtkWidget         *btn_submit;
-  GtkWidget         *btn_keyboard;
-  guint              idle_timer;
-  gint64             last_input;
-  PhoshAuth         *auth;
-  GSettings         *lockscreen_settings;
+  GtkWidget          *box_unlock;
+  GtkWidget          *keypad_revealer;
+  GtkWidget          *keypad;
+  GtkWidget          *entry_pin;
+  GtkGesture         *long_press_del_gesture;
+  GtkWidget          *lbl_unlock_status;
+  GtkWidget          *btn_submit;
+  GtkWidget          *btn_keyboard;
+  guint idle_timer;
+  gint64 last_input;
+  PhoshAuth          *auth;
+  GSettings          *lockscreen_settings;
+
+  /* Volume Gesture */
+  struct {
+    GtkGesture *gesture;
+    double      x_start, y_start;
+    double      base;
+  } brightness;
 
   /* extra page */
   GtkWidget         *extra_page;
@@ -116,7 +123,7 @@ typedef struct {
   CuiCallDisplay    *call_display;
 
   PhoshCallsManager *calls_manager;
-  char              *active; /* opaque handle to the active call */
+  char *active;              /* opaque handle to the active call */
 
   PhoshLockscreenBg *background;
 } PhoshLockscreenPrivate;
@@ -124,6 +131,83 @@ typedef struct {
 G_DEFINE_TYPE_WITH_PRIVATE (PhoshLockscreen, phosh_lockscreen, PHOSH_TYPE_LAYER_SURFACE)
 
 
+static gboolean
+is_valid (PhoshLockscreen *self, GtkGesture *gesture, double *x_center)
+{
+  double y_center, scale;
+  uint height;
+  gboolean active;
+
+  active = gtk_gesture_get_bounding_box_center (gesture, x_center, &y_center);
+  if (!active) {
+    return FALSE;
+  }
+
+  height = gtk_widget_get_allocated_height (GTK_WIDGET (self));
+  /* Swipe must happen in the upper screen half */
+  if (y_center > 0.5 * height) {
+    return FALSE;
+  }
+
+  scale = gtk_gesture_zoom_get_scale_delta (GTK_GESTURE_ZOOM (gesture));
+  /* We don't want to actually zoom */
+  if (scale >= 0.9 && scale <= 1.1) {
+    return TRUE;
+  }
+
+  return FALSE;
+}
+
+
+static void
+on_zoom_gesture_update (PhoshLockscreen  *self,
+                        GdkEventSequence *sequence,
+                        GtkGesture       *gesture)
+{
+  PhoshLockscreenPrivate *priv = phosh_lockscreen_get_instance_private (self);
+  PhoshBrightnessManager *manager;
+  double x_center;
+  uint width;
+  double brightness;
+
+  g_return_if_fail (PHOSH_IS_LOCKSCREEN (self));
+
+  if (!is_valid (self, gesture, &x_center))
+    return;
+
+  manager = phosh_shell_get_brightness_manager (phosh_shell_get_default ());
+  width = gtk_widget_get_allocated_width (GTK_WIDGET (self));
+  brightness = priv->brightness.base + (x_center - priv->brightness.x_start) / width;
+
+  g_debug ("Brightness gesture updating: %f", brightness);
+  phosh_brightness_manager_set_value (manager, CLAMP (brightness, 0.0, 1.0), TRUE);
+}
+
+
+static void
+on_zoom_gesture_begin (PhoshLockscreen  *self,
+                       GdkEventSequence *sequence,
+                       GtkGesture       *gesture)
+{
+  gdouble x_center;
+  PhoshLockscreenPrivate *priv = phosh_lockscreen_get_instance_private (self);
+  PhoshBrightnessManager *manager;
+
+  g_return_if_fail (PHOSH_IS_LOCKSCREEN (self));
+
+  if (!is_valid (self, gesture, &x_center))
+    return;
+
+  gtk_gesture_set_state (gesture, GTK_EVENT_SEQUENCE_CLAIMED);
+  manager = phosh_shell_get_brightness_manager (phosh_shell_get_default ());
+  priv->brightness.x_start = x_center;
+  priv->brightness.base = phosh_brightness_manager_get_value (manager);
+  g_debug ("Brightness gesture start at: %f (%f)",
+           priv->brightness.x_start,
+           priv->brightness.base);
+}
+
+
 static void
 phosh_lockscreen_map (GtkWidget *widget)
 {
@@ -289,10 +373,12 @@ focus_pin_entry (PhoshLockscreen *self, gboolean enable_osk)
   gtk_entry_grab_focus_without_selecting (GTK_ENTRY (priv->entry_pin));
 }
 
-/* callback of async auth task */
+
 static void
-auth_async_cb (PhoshAuth *auth, GAsyncResult *result, PhoshLockscreen *self)
+on_auth_authenticate_ready (GObject *source_object, GAsyncResult *result, gpointer user_data)
 {
+  PhoshAuth *auth = PHOSH_AUTH (source_object);
+  g_autoptr (PhoshLockscreen) self = PHOSH_LOCKSCREEN (user_data);
   PhoshLockscreenPrivate *priv;
   GError *error = NULL;
   gboolean authenticated;
@@ -314,7 +400,6 @@ auth_async_cb (PhoshAuth *auth, GAsyncResult *result, PhoshLockscreen *self)
   }
   g_clear_object (&priv->auth);
   priv->last_input = g_get_monotonic_time ();
-  g_object_unref (self);
 }
 
 
@@ -469,29 +554,12 @@ wall_clock_notify_cb (PhoshLockscreen *self,
   PhoshLockscreenPrivate *priv = phosh_lockscreen_get_instance_private (self);
   const char *time;
   g_autofree char *date = NULL;
-  g_auto (GStrv) parts = NULL;
+  g_autofree char *stripped = NULL;
 
   time = phosh_wall_clock_get_clock (wall_clock, TRUE);
 
-  /* Strip " {A,P}M" from 12h time format to look less cramped */
-  if (g_str_has_suffix (time, "AM") || g_str_has_suffix (time, "PM")) {
-    parts = g_strsplit (time, " ", -1);
-
-    if (g_strv_length (parts) == 2) {
-      /* Glib >= 2.74: padding with figure-space */
-      if (g_str_has_prefix (parts[0], "\u2007")) {
-        time = parts[0] + strlen("\u2007");
-      } else {
-        time = parts[0];
-      }
-    /* Glib < 2.74: padding with ascii space */
-    } else if (g_strv_length (parts) == 3) {
-      time = parts[1];
-    } else {
-      g_warning ("Can't parse time format: %s", time);
-    }
-  }
-  gtk_label_set_text (GTK_LABEL (priv->lbl_clock), time);
+  stripped = phosh_wall_clock_strip_am_pm (wall_clock, time);
+  gtk_label_set_text (GTK_LABEL (priv->lbl_clock), stripped);
 
   date = phosh_wall_clock_local_date (wall_clock);
   gtk_label_set_label (GTK_LABEL (priv->lbl_date), date);
@@ -542,7 +610,7 @@ carousel_page_changed_cb (PhoshLockscreen *self,
 
 
 static void
-update_active_call (PhoshLockscreen *self, const gchar *path)
+update_active_call (PhoshLockscreen *self, const char *path)
 {
   PhoshLockscreenPrivate *priv = phosh_lockscreen_get_instance_private (self);
   PhoshCall *call;
@@ -561,7 +629,7 @@ update_active_call (PhoshLockscreen *self, const gchar *path)
 
 
 static void
-on_calls_call_added (PhoshLockscreen *self, const gchar *path)
+on_calls_call_added (PhoshLockscreen *self, const char *path)
 {
   PhoshLockscreenPrivate *priv;
 
@@ -576,7 +644,7 @@ on_calls_call_added (PhoshLockscreen *self, const gchar *path)
 
 
 static void
-on_calls_call_removed (PhoshLockscreen *self, const gchar *path)
+on_calls_call_removed (PhoshLockscreen *self, const char *path)
 {
   PhoshLockscreenPrivate *priv;
 
@@ -647,9 +715,7 @@ on_deck_transition_running_changed (PhoshLockscreen *self)
   if (hdy_deck_get_transition_running (priv->deck))
     return;
 
-  if (hdy_deck_get_visible_child (priv->deck) != priv->carousel)
-    return;
-
+  /* Otherwise we might see stale information */
   /* See https://gitlab.gnome.org/World/Phosh/phosh/-/issues/922 */
   gtk_widget_queue_draw (priv->lbl_clock);
 }
@@ -678,36 +744,25 @@ create_notification_row (gpointer item, gpointer data)
 
 
 static void
-animate_clock (PhoshLockscreen *self)
-{
-  PhoshLockscreenPrivate *priv;
-
-  priv = phosh_lockscreen_get_instance_private (self);
-
-  /* Use small clock if any additional info elements are revealed */
-  phosh_util_toggle_style_class (priv->box_datetime, LOCKSCREEN_SMALL_DATE_AND_TIME_CLASS,
-                                 !!priv->reveals);
-}
-
-
-static void
-on_info_reveal_child_changed (PhoshLockscreen *self, GParamSpec *pspec, GtkRevealer *revealer)
+on_info_reveal_child_changed (PhoshLockscreen *self)
 {
   PhoshLockscreenPrivate *priv;
+  gboolean has_info = FALSE;
 
   g_return_if_fail (PHOSH_IS_LOCKSCREEN (self));
   priv = phosh_lockscreen_get_instance_private (self);
 
-  if (gtk_revealer_get_reveal_child (revealer))
-    priv->reveals++;
-  else
-    priv->reveals--;
+  has_info |= gtk_revealer_get_reveal_child (priv->rev_notifications);
+  has_info |= gtk_revealer_get_reveal_child (priv->rev_call_notifications);
+  has_info |= gtk_revealer_get_reveal_child (priv->rev_media_player);
 
-  animate_clock (self);
+  /* Use small clock if any additional info elements are revealed */
+  phosh_util_toggle_style_class (priv->box_datetime,
+                                 LOCKSCREEN_SMALL_DATE_AND_TIME_CLASS,
+                                 has_info);
 }
 
 
-
 static void
 on_call_notification_activated (PhoshLockscreen *self,
                                 GtkListBoxRow   *row,
@@ -899,6 +954,7 @@ phosh_lockscreen_constructed (GObject *object)
     phosh_widget_box_set_plugins (PHOSH_WIDGET_BOX (priv->widget_box), plugins);
 
   on_deck_visible_child_changed (self, NULL, priv->deck);
+  on_info_reveal_child_changed (self);
 
   phosh_lockscreen_add_background (self);
 }
@@ -929,6 +985,7 @@ phosh_lockscreen_dispose (GObject *object)
   PhoshLockscreen *self = PHOSH_LOCKSCREEN (object);
   PhoshLockscreenPrivate *priv = phosh_lockscreen_get_instance_private (self);
 
+  g_clear_object (&priv->brightness.gesture);
   g_clear_object (&priv->notification_settings);
   g_clear_handle_id (&priv->idle_timer, g_source_remove);
   g_clear_object (&priv->calls_manager);
@@ -989,7 +1046,7 @@ on_unlock_submit (PhoshLockscreen *self)
   phosh_auth_authenticate_async (priv->auth,
                                  input,
                                  NULL,
-                                 (GAsyncReadyCallback)auth_async_cb,
+                                 on_auth_authenticate_ready,
                                  g_object_ref (self));
 }
 
@@ -1136,6 +1193,14 @@ phosh_lockscreen_init (PhoshLockscreen *self)
   /* LTR doesn't work for the deck
    * https://gitlab.gnome.org/World/Phosh/phosh/-/issues/1132 */
   gtk_widget_set_direction (GTK_WIDGET (priv->deck), GTK_TEXT_DIR_LTR);
+
+  priv->brightness.gesture = gtk_gesture_zoom_new (GTK_WIDGET (self));
+  g_object_connect (priv->brightness.gesture,
+                    "swapped-object-signal::begin", on_zoom_gesture_begin, self,
+                    "swapped-object-signal::update", on_zoom_gesture_update, self,
+                    NULL);
+  gtk_event_controller_set_propagation_phase (GTK_EVENT_CONTROLLER (priv->brightness.gesture),
+                                              GTK_PHASE_CAPTURE);
 }
 
 
