@@ -11,16 +11,12 @@
 #include "phosh-config.h"
 
 #include "activity.h"
-#include "app-grid-button.h"
 #include "app-grid.h"
 #include "overview.h"
-#include "wlr-screencopy-unstable-v1-client-protocol.h"
-#include "phosh-private-client-protocol.h"
 #include "phosh-wayland.h"
 #include "shell-priv.h"
 #include "toplevel-manager.h"
 #include "toplevel-thumbnail.h"
-#include "util.h"
 
 #include <gio/gdesktopappinfo.h>
 
@@ -55,19 +51,17 @@ enum {
 static GParamSpec *props[LAST_PROP];
 
 
-typedef struct
-{
+typedef struct {
   /* Running activities */
-  GtkWidget *carousel_running_activities;
-  GtkWidget *app_grid;
+  GtkWidget     *carousel_running_activities;
+  GtkWidget     *app_grid;
   PhoshActivity *activity;
 
-  int       has_activities;
+  int has_activities;
 } PhoshOverviewPrivate;
 
 
-struct _PhoshOverview
-{
+struct _PhoshOverview {
   GtkBoxClass parent;
 };
 
@@ -107,10 +101,9 @@ get_toplevel_from_activity (PhoshActivity *activity)
 
 
 static PhoshActivity *
-find_activity_by_toplevel (PhoshOverview        *self,
-                           PhoshToplevel        *needle)
+find_activity_by_toplevel (PhoshOverview *self, PhoshToplevel *needle)
 {
-  g_autoptr(GList) children;
+  g_autoptr (GList) children;
   PhoshActivity *activity = NULL;
   PhoshOverviewPrivate *priv = phosh_overview_get_instance_private (self);
 
@@ -137,6 +130,7 @@ scroll_to_activity (PhoshOverview *self, PhoshActivity *activity)
   gtk_widget_grab_focus (GTK_WIDGET (activity));
 }
 
+
 static void
 on_activity_clicked (PhoshOverview *self, PhoshActivity *activity)
 {
@@ -147,9 +141,9 @@ on_activity_clicked (PhoshOverview *self, PhoshActivity *activity)
   toplevel = get_toplevel_from_activity (activity);
   g_return_if_fail (toplevel);
 
-  g_debug("Will raise %s (%s)",
-          phosh_activity_get_app_id (activity),
-          phosh_toplevel_get_title (toplevel));
+  g_debug ("Will raise %s (%s)",
+           phosh_activity_get_app_id (activity),
+           phosh_toplevel_get_title (toplevel));
 
   phosh_toplevel_activate (toplevel, phosh_wayland_get_wl_seat (phosh_wayland_get_default ()));
   g_signal_emit (self, signals[ACTIVITY_RAISED], 0);
@@ -253,14 +247,25 @@ request_thumbnail (PhoshActivity *activity, PhoshToplevel *toplevel)
   g_return_if_fail (PHOSH_IS_TOPLEVEL (toplevel));
   scale = gtk_widget_get_scale_factor (GTK_WIDGET (activity));
   phosh_activity_get_thumbnail_allocation (activity, &allocation);
-  thumbnail = phosh_toplevel_thumbnail_new_from_toplevel (toplevel, allocation.width * scale, allocation.height * scale);
-  g_signal_connect_object (thumbnail, "notify::ready", G_CALLBACK (on_thumbnail_ready_changed), activity, 0);
+  thumbnail = phosh_toplevel_thumbnail_new_from_toplevel (toplevel, allocation.width * scale,
+                                                          allocation.height * scale);
+  g_signal_connect_object (thumbnail,
+                           "notify::ready",
+                           G_CALLBACK (on_thumbnail_ready_changed),
+                           activity,
+                           0);
 }
 
 
 static void
-on_activity_resized (PhoshActivity *activity, GtkAllocation *alloc, PhoshToplevel *toplevel)
+on_activity_resized (PhoshOverview *self, GtkAllocation *alloc, PhoshActivity *activity)
 {
+  PhoshToplevel *toplevel;
+
+  g_return_if_fail (PHOSH_IS_ACTIVITY (activity));
+  toplevel = g_object_get_data (G_OBJECT (activity), "toplevel");
+  g_return_if_fail (PHOSH_IS_TOPLEVEL (toplevel));
+
   request_thumbnail (activity, toplevel);
 }
 
@@ -275,7 +280,8 @@ on_activity_has_focus_changed (PhoshOverview *self, GParamSpec *pspec, PhoshActi
   priv = phosh_overview_get_instance_private (self);
 
   if (gtk_widget_has_focus (GTK_WIDGET (activity)))
-    hdy_carousel_scroll_to (HDY_CAROUSEL (priv->carousel_running_activities), GTK_WIDGET (activity));
+    hdy_carousel_scroll_to (HDY_CAROUSEL (priv->carousel_running_activities),
+                            GTK_WIDGET (activity));
 }
 
 
@@ -352,16 +358,17 @@ add_activity (PhoshOverview *self, PhoshToplevel *toplevel)
                     "swapped-signal::clicked", on_activity_clicked, self,
                     "swapped-signal::closed", on_activity_closed, self,
                     "swapped-signal::fullscreened", on_activity_fullscreened, self,
+                    "swapped-signal::notify::has-focus", on_activity_has_focus_changed, self,
+                    "swapped-signal::resized", on_activity_resized, self,
                     NULL);
 
-  g_signal_connect_object (toplevel, "closed", G_CALLBACK (on_toplevel_closed), self, 0);
-  g_signal_connect_object (toplevel, "notify::activated", G_CALLBACK (on_toplevel_activated_changed), self, 0);
+  g_object_connect (toplevel,
+                    "object-signal::closed", on_toplevel_closed, self,
+                    "object-signal::notify::activated", on_toplevel_activated_changed, self,
+                    NULL);
   g_object_bind_property (toplevel, "maximized", activity, "maximized", G_BINDING_DEFAULT);
   g_object_bind_property (toplevel, "fullscreen", activity, "fullscreen", G_BINDING_DEFAULT);
 
-  g_signal_connect (activity, "resized", G_CALLBACK (on_activity_resized), toplevel);
-  g_signal_connect_swapped (activity, "notify::has-focus", G_CALLBACK (on_activity_has_focus_changed), self);
-
   if (phosh_toplevel_is_activated (toplevel)) {
     scroll_to_activity (self, PHOSH_ACTIVITY (activity));
     priv->activity = PHOSH_ACTIVITY (activity);
@@ -369,18 +376,30 @@ add_activity (PhoshOverview *self, PhoshToplevel *toplevel)
 }
 
 
+static void
+set_has_activities (PhoshOverview *self)
+{
+  PhoshOverviewPrivate *priv = phosh_overview_get_instance_private (self);
+  gboolean has_activities;
+
+  has_activities = !!hdy_carousel_get_n_pages (HDY_CAROUSEL (priv->carousel_running_activities));
+  if (priv->has_activities == has_activities)
+    return;
+
+  priv->has_activities = has_activities;
+  gtk_widget_set_visible (priv->carousel_running_activities, has_activities);
+  g_object_notify_by_pspec (G_OBJECT (self), props[PROP_HAS_ACTIVITIES]);
+}
+
+
 static void
 get_running_activities (PhoshOverview *self)
 {
-  PhoshOverviewPrivate *priv;
-  PhoshToplevelManager *toplevel_manager = phosh_shell_get_toplevel_manager (phosh_shell_get_default ());
+  PhoshShell *shell = phosh_shell_get_default ();
+  PhoshToplevelManager *toplevel_manager = phosh_shell_get_toplevel_manager (shell);
   guint toplevels_num = phosh_toplevel_manager_get_num_toplevels (toplevel_manager);
-  g_return_if_fail (PHOSH_IS_OVERVIEW (self));
-  priv = phosh_overview_get_instance_private (self);
 
-  priv->has_activities = !!toplevels_num;
-  if (toplevels_num == 0)
-    gtk_widget_set_visible (priv->carousel_running_activities, FALSE);
+  set_has_activities (self);
 
   for (guint i = 0; i < toplevels_num; i++) {
     PhoshToplevel *toplevel = phosh_toplevel_manager_get_toplevel (toplevel_manager, i);
@@ -390,9 +409,7 @@ get_running_activities (PhoshOverview *self)
 
 
 static void
-toplevel_added_cb (PhoshOverview        *self,
-                   PhoshToplevel        *toplevel,
-                   PhoshToplevelManager *manager)
+on_toplevel_added (PhoshOverview *self, PhoshToplevel *toplevel, PhoshToplevelManager *manager)
 {
   g_return_if_fail (PHOSH_IS_OVERVIEW (self));
   g_return_if_fail (PHOSH_IS_TOPLEVEL (toplevel));
@@ -402,9 +419,7 @@ toplevel_added_cb (PhoshOverview        *self,
 
 
 static void
-toplevel_changed_cb (PhoshOverview        *self,
-                     PhoshToplevel        *toplevel,
-                     PhoshToplevelManager *manager)
+on_toplevel_changed (PhoshOverview *self, PhoshToplevel *toplevel, PhoshToplevelManager *manager)
 {
   PhoshActivity *activity;
 
@@ -423,24 +438,11 @@ toplevel_changed_cb (PhoshOverview        *self,
 
 
 static void
-num_toplevels_cb (PhoshOverview        *self,
-                  GParamSpec           *pspec,
-                  PhoshToplevelManager *manager)
+on_n_pages_changed (PhoshOverview *self)
 {
-  PhoshOverviewPrivate *priv;
-  gboolean has_activities;
-
   g_return_if_fail (PHOSH_IS_OVERVIEW (self));
-  g_return_if_fail (PHOSH_IS_TOPLEVEL_MANAGER (manager));
-  priv = phosh_overview_get_instance_private (self);
 
-  has_activities = !!phosh_toplevel_manager_get_num_toplevels (manager);
-  if (priv->has_activities == has_activities)
-    return;
-
-  priv->has_activities = has_activities;
-  gtk_widget_set_visible (priv->carousel_running_activities, has_activities);
-  g_object_notify_by_pspec (G_OBJECT (self), props[PROP_HAS_ACTIVITIES]);
+  set_has_activities (self);
 }
 
 
@@ -468,9 +470,7 @@ phosh_overview_size_allocate (GtkWidget     *widget,
 
 
 static void
-app_launched_cb (PhoshOverview *self,
-                 GAppInfo      *info,
-                 GtkWidget     *widget)
+on_app_launched (PhoshOverview *self, GAppInfo *info, GtkWidget *widget)
 {
   g_return_if_fail (PHOSH_IS_OVERVIEW (self));
 
@@ -479,9 +479,7 @@ app_launched_cb (PhoshOverview *self,
 
 
 static void
-page_changed_cb (PhoshOverview *self,
-                 guint          index,
-                 HdyCarousel   *carousel)
+on_page_changed (PhoshOverview *self, guint index, HdyCarousel *carousel)
 {
   PhoshActivity *activity;
   PhoshToplevel *toplevel;
@@ -515,34 +513,17 @@ static void
 phosh_overview_constructed (GObject *object)
 {
   PhoshOverview *self = PHOSH_OVERVIEW (object);
-  PhoshOverviewPrivate *priv = phosh_overview_get_instance_private (self);
   PhoshToplevelManager *toplevel_manager =
-      phosh_shell_get_toplevel_manager (phosh_shell_get_default ());
+    phosh_shell_get_toplevel_manager (phosh_shell_get_default ());
 
   G_OBJECT_CLASS (phosh_overview_parent_class)->constructed (object);
 
-  g_signal_connect_object (toplevel_manager, "toplevel-added",
-                           G_CALLBACK (toplevel_added_cb),
-                           self,
-                           G_CONNECT_SWAPPED);
-
-  g_signal_connect_object (toplevel_manager, "toplevel-changed",
-                           G_CALLBACK (toplevel_changed_cb),
-                           self,
-                           G_CONNECT_SWAPPED);
-
-  g_signal_connect_object (toplevel_manager, "notify::num-toplevels",
-                           G_CALLBACK (num_toplevels_cb),
-                           self,
-                           G_CONNECT_SWAPPED);
+  g_object_connect (toplevel_manager,
+                    "swapped-object-signal::toplevel-added", on_toplevel_added, self,
+                    "swapped-object-signal::toplevel-changed", on_toplevel_changed, self,
+                    NULL);
 
   get_running_activities (self);
-
-  g_signal_connect_swapped (priv->app_grid, "app-launched",
-                            G_CALLBACK (app_launched_cb), self);
-
-  g_signal_connect_swapped (priv->carousel_running_activities, "page-changed",
-                            G_CALLBACK (page_changed_cb), self);
 }
 
 
@@ -566,6 +547,8 @@ phosh_overview_class_init (PhoshOverviewClass *klass)
                           FALSE,
                           G_PARAM_READABLE | G_PARAM_STATIC_STRINGS);
 
+  g_object_class_install_properties (object_class, LAST_PROP, props);
+
   signals[ACTIVITY_LAUNCHED] =
     g_signal_new ("activity-launched",
                   G_TYPE_FROM_CLASS (klass),
@@ -595,12 +578,16 @@ phosh_overview_class_init (PhoshOverviewClass *klass)
                   G_TYPE_NONE, 0);
 
   /* ensure used custom types */
-  PHOSH_TYPE_APP_GRID;
+  g_type_ensure (PHOSH_TYPE_APP_GRID);
+
   gtk_widget_class_set_template_from_resource (widget_class, "/mobi/phosh/ui/overview.ui");
 
   gtk_widget_class_bind_template_child_private (widget_class, PhoshOverview, app_grid);
   gtk_widget_class_bind_template_child_private (widget_class, PhoshOverview,
                                                 carousel_running_activities);
+  gtk_widget_class_bind_template_callback (widget_class, on_app_launched);
+  gtk_widget_class_bind_template_callback (widget_class, on_n_pages_changed);
+  gtk_widget_class_bind_template_callback (widget_class, on_page_changed);
 
   gtk_widget_class_set_css_name (widget_class, "phosh-overview");
 }
@@ -609,6 +596,9 @@ phosh_overview_class_init (PhoshOverviewClass *klass)
 static void
 phosh_overview_init (PhoshOverview *self)
 {
+  PhoshOverviewPrivate *priv = phosh_overview_get_instance_private (self);
+
+  priv->has_activities = -1;
   gtk_widget_init_template (GTK_WIDGET (self));
 }
 
@@ -624,7 +614,7 @@ void
 phosh_overview_refresh (PhoshOverview *self)
 {
   PhoshOverviewPrivate *priv;
-  g_return_if_fail(PHOSH_IS_OVERVIEW (self));
+  g_return_if_fail (PHOSH_IS_OVERVIEW (self));
   priv = phosh_overview_get_instance_private (self);
 
   if (priv->activity) {
@@ -639,7 +629,7 @@ phosh_overview_reset (PhoshOverview *self)
 {
   PhoshOverviewPrivate *priv;
 
-  g_return_if_fail(PHOSH_IS_OVERVIEW (self));
+  g_return_if_fail (PHOSH_IS_OVERVIEW (self));
   priv = phosh_overview_get_instance_private (self);
 
   phosh_app_grid_reset (PHOSH_APP_GRID (priv->app_grid));
@@ -651,7 +641,7 @@ phosh_overview_focus_app_search (PhoshOverview *self)
 {
   PhoshOverviewPrivate *priv;
 
-  g_return_if_fail(PHOSH_IS_OVERVIEW (self));
+  g_return_if_fail (PHOSH_IS_OVERVIEW (self));
   priv = phosh_overview_get_instance_private (self);
   phosh_app_grid_focus_search (PHOSH_APP_GRID (priv->app_grid));
 }
@@ -662,7 +652,7 @@ phosh_overview_handle_search (PhoshOverview *self, GdkEvent *event)
 {
   PhoshOverviewPrivate *priv;
 
-  g_return_val_if_fail(PHOSH_IS_OVERVIEW (self), GDK_EVENT_PROPAGATE);
+  g_return_val_if_fail (PHOSH_IS_OVERVIEW (self), GDK_EVENT_PROPAGATE);
   priv = phosh_overview_get_instance_private (self);
   return phosh_app_grid_handle_search (PHOSH_APP_GRID (priv->app_grid), event);
 }
