@@ -8,7 +8,7 @@
 
 #define G_LOG_DOMAIN "phosh-thumbnail"
 
-#include "thumbnail.h"
+#include "thumbnail-priv.h"
 
 /**
  * PhoshThumbnail:
@@ -23,87 +23,38 @@ enum {
 };
 static GParamSpec *props[PROP_LAST_PROP];
 
-G_DEFINE_TYPE (PhoshThumbnail, phosh_thumbnail, G_TYPE_OBJECT);
+typedef struct _PhoshThumbnailPrivate {
+  gboolean ready;
+} PhoshThumbnailPrivate;
+
+G_DEFINE_TYPE_WITH_PRIVATE (PhoshThumbnail, phosh_thumbnail, G_TYPE_OBJECT);
 
 
 static void
-phosh_thumbnail_set_ready (PhoshThumbnail *self, gboolean ready)
-{
-  g_object_notify_by_pspec (G_OBJECT (self), props[PROP_READY]);
-}
-
-static void
-phosh_thumbnail_set_property (GObject *object,
-                              guint property_id,
-                              const GValue *value,
+phosh_thumbnail_get_property (GObject    *object,
+                              guint       property_id,
+                              GValue     *value,
                               GParamSpec *pspec)
 {
   PhoshThumbnail *self = PHOSH_THUMBNAIL (object);
-  PhoshThumbnailClass *klass = PHOSH_THUMBNAIL_GET_CLASS (self);
 
   switch (property_id) {
-    case PROP_READY:
-      klass->set_ready (self, g_value_get_boolean (value));
-      break;
-    default:
-      G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
-      break;
+  case PROP_READY:
+    g_value_set_boolean (value, phosh_thumbnail_is_ready (self));
+    break;
+  default:
+    G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+    break;
   }
 }
 
 
-static void
-phosh_thumbnail_get_property (GObject *object,
-                                      guint property_id,
-                                      GValue *value,
-                                      GParamSpec *pspec)
-{
-  PhoshThumbnail *self = PHOSH_THUMBNAIL (object);
-
-  switch (property_id) {
-    case PROP_READY:
-      g_value_set_boolean (value, phosh_thumbnail_is_ready (self));
-      break;
-    default:
-      G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
-      break;
-  }
-}
-
-
-static void
-phosh_thumbnail_constructed (GObject *object)
-{
-  G_OBJECT_CLASS (phosh_thumbnail_parent_class)->constructed (object);
-}
-
-
-static void
-phosh_thumbnail_dispose (GObject *object)
-{
-  G_OBJECT_CLASS (phosh_thumbnail_parent_class)->dispose (object);
-}
-
-
-static void
-phosh_thumbnail_finalize (GObject *object)
-{
-  G_OBJECT_CLASS (phosh_thumbnail_parent_class)->finalize (object);
-}
-
-
 static void
 phosh_thumbnail_class_init (PhoshThumbnailClass *klass)
 {
   GObjectClass *object_class = G_OBJECT_CLASS (klass);
 
-  object_class->constructed = phosh_thumbnail_constructed;
-  object_class->dispose = phosh_thumbnail_dispose;
-  object_class->finalize = phosh_thumbnail_finalize;
   object_class->get_property = phosh_thumbnail_get_property;
-  object_class->set_property = phosh_thumbnail_set_property;
-
-  klass->set_ready = phosh_thumbnail_set_ready;
 
   /**
    * PhoshThumbnail:ready:
@@ -125,7 +76,7 @@ phosh_thumbnail_init (PhoshThumbnail *self)
 }
 
 
-void *
+gpointer
 phosh_thumbnail_get_image (PhoshThumbnail *self)
 {
   PhoshThumbnailClass *klass;
@@ -156,13 +107,25 @@ phosh_thumbnail_get_size (PhoshThumbnail *self, guint *width, guint *height, gui
 gboolean
 phosh_thumbnail_is_ready (PhoshThumbnail *self)
 {
-  PhoshThumbnailClass *klass;
+  PhoshThumbnailPrivate *priv = phosh_thumbnail_get_instance_private (self);
 
   g_return_val_if_fail (PHOSH_IS_THUMBNAIL (self), FALSE);
 
-  klass = PHOSH_THUMBNAIL_GET_CLASS (self);
-  g_return_val_if_fail (klass->is_ready != NULL, FALSE);
-
-  return klass->is_ready (self);
+  return priv->ready;
 }
 
+
+void
+phosh_thumbnail_set_ready (PhoshThumbnail *self, gboolean ready)
+{
+  PhoshThumbnailPrivate *priv = phosh_thumbnail_get_instance_private (self);
+
+  g_return_if_fail (PHOSH_IS_THUMBNAIL (self));
+
+  if (priv->ready == ready)
+    return;
+
+  priv->ready = ready;
+  g_object_notify_by_pspec (G_OBJECT (self), props[PROP_READY]);
+
+}
