@@ -7,8 +7,7 @@
  */
 
 #include "phosh-idle-dbus.h"
-#include "log.h"
-#include "shell.h"
+#include "shell-priv.h"
 
 #include "testlib-full-shell.h"
 
